/*
Copyright 2020 Appboxo pte. ltd.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import 'package:flutter/services.dart';

class AppboxoSdk {
  static const MethodChannel _channel = const MethodChannel('appboxo_sdk');
  static const EventChannel _customEventChannel = const EventChannel('appboxo_sdk_custom_events');

  static void setConfig(String clientId) {
    _channel.invokeMethod("setConfig", {'client_id': clientId});
  }

  static void openMiniApp(String appId, String payload, {String data = ""}) {
    _channel.invokeMethod("openMiniApp", {'app_id': appId, 'payload': payload, 'data': data});
  }

  static void hideAllMiniApps(){
    _channel.invokeMethod("hideAllMiniApps");
  }

  static Stream<CustomEvent> customEvents() {
    return _customEventChannel.receiveBroadcastStream().map((dynamic event) => CustomEvent.fromJson(event));
  }

  static void sendEvent(CustomEvent customEvent) {
    _channel.invokeMethod("sendEvent", {'custom_event': customEvent.toJson()});
  }
}

class CustomEvent {
  String appId;
  String requestId;
  String type;
  String errorType;
  Map payload;

  CustomEvent(this.appId, this.requestId, this.type, this.errorType, this.payload);

  CustomEvent.fromJson(Map<dynamic, dynamic> json)
      : appId = json['appId'],
        requestId = json['requestId'],
        type = json['type'],
        errorType = json['errorType'],
        payload = json['payload'];

  Map<String, dynamic> toJson() =>
      {'appId': appId, 'requestId': requestId, 'type': type, 'errorType': errorType, 'payload': payload};
}
